<?php
/*
Plugin Name: Front-end Categories Management
Plugin URI:
Description: A handy and simple plugin for creating/editing categories/terms and sub-categories on the WordPress user end.
Author: manishkrag
Author URI:
Version: 1.1
*/

function include_css_js_files() {
	wp_enqueue_script(
		'front-end-cat-script',
		plugin_dir_url( __FILE__ ) . 'js/front-end-cat.js',
		array( 'jquery' )
	);
	wp_localize_script( 'front-end-cat-script', 'termAjax', array( 'ajaxurl' => admin_url( 'admin-ajax.php' ) ) );
	wp_enqueue_style( 'front-end-cat-css', plugins_url( 'css/front-end-cat.css', __FILE__ ) );
}

function print_category_create_form() {
?>
	<div class="new-term">
		<form action="" method="post">
			<?php wp_nonce_field( 'frontend_category_management' ); ?>
			<label>Category Name:</label>
			<input type="text" name="newcategory" value="" /><br />

			<label>Parent</label>
			<?php
	$args = array(
		'hide_empty' => 0,
		'name' => 'cat-parent',
		'orderby ' => 'id',
		'order' => 'DESC',
		'hierarchical' => true,
		'show_option_none' => '-'
	);

	wp_dropdown_categories( $args ) ;?>

			<input type="submit" name="submit-cat-form" value="Create" />
		</form>
	</div>
	<?php
}

function print_existing_category() {
	$categories = (array) get_terms( 'category', array( 'get' => 'all' ) );

	$table = '<table>';
	$table_head = '<tr><th>Category Name</th><th>Post Count</th><th>Actions</th></tr>';
	$table_body = '';
	foreach ( $categories as $category ) {
		$edit = '<a href="#" class="edit">Edit</a>';
		$save = '<a href="#" class="save hide">Save</a>';
		$delete = ( 1 != $category->term_id ) ? '<a href="#" class="delete">Delete</a>' : 'Can\'t be delete';
		$term_eidt_field = '<input class="term-id-' . $category->term_id . '" type="text" name="term-name" value="' . $category->name . '" />';

		$table_body .= '<tr><td><span class="term-name" id="term-id-' . $category->term_id . '">' . $category->name . '</span><span class="term-edit hide">' . $term_eidt_field . '</span></td><td>' . $category->count . '</td><td><input type="hidden" name="term-id" value="' . $category->term_id . '" />' . $edit . $save . '&nbsp;&nbsp;' . $delete . '</td></tr>';

	}
	$table_footer = '</table>';
	echo '<div class="existing-terms"><h3>Modify existing category</h3>' . $table . $table_head . $table_body . $table_footer . '</div>';
}

function fec_subcat_create() {
	global $current_user;
	// Load style and script files
	include_css_js_files();
	
	if ( array_key_exists( 'administrator', $current_user->caps ) ) {
		if ( array_key_exists( '_wpnonce', $_REQUEST ) ) {
			$valid_nonce = wp_verify_nonce( $_REQUEST['_wpnonce'], 'frontend_category_management' );
			if ( $valid_nonce ) {
				if ( isset( $_POST['submit-cat-form'] ) ) {
					if ( !empty( $_POST['newcategory'] ) ) {
						$cat_ID = get_cat_ID( $_POST['newcategory'] );

						if ( 0 == $cat_ID ) {
							$subcat_name = $_POST['newcategory'];
							$parentCatID = $_POST['cat-parent'];
							$arg = array( 'description' => $subcat_name, 'parent' => $parentCatID );
							$new_subcat_ID = wp_insert_term( $subcat_name, "category", $arg );

							echo '<div id="message" class="updated"><p>Category created successfully.</p></div>';
						} else {
							echo '<div id="message" class="error"><p>Category already exists!</p></div>';
						}
					}
				}
			}
		}
	} else {
		echo '<div id="message" class="error"><p>You do not have sufficient permission.</p></div>';
	}

	// Get for HTML
	print_category_create_form();

	print_existing_category();

}

// Shortcode for creating sub-category
add_shortcode( 'fecm-front-end-subcat', 'fec_subcat_create' );

add_action( 'wp_ajax_fecm_update_term', 'fecm_update_term' );
function fecm_update_term() {
	global $current_user;
	
	if ( array_key_exists( 'administrator', $current_user->caps ) ) {
		$term_name = $_POST['termEditedName'];
		$term_id = $_POST['termEditId'];
		$result = wp_update_term( $term_id, 'category', array( 'name' => $term_name ) );

		if ( array_key_exists( 'term_id', $result ) ) {
			echo true;
		} else {
			echo false;
		}
		exit;
	}
}


add_action( 'wp_ajax_fecm_delete_term', 'fecm_delete_term' );
function fecm_delete_term() {
	global $current_user;

	if ( array_key_exists( 'administrator', $current_user->caps ) ) {
		$term_id = $_POST['termEditId'];
		echo wp_delete_term( $term_id, 'category' );
		exit;
	}

	echo false;
	exit;
}
